#ifndef __HUB_H__
#define __HUB_H__

#include "scan.h"

typedef struct _GL_USB_HUB_NODE
{
    int busNum;
    int devNum;
} GL_USB_HUB_NODE, *PGL_USB_HUB_NODE;

typedef struct _GL_CHIP_INFO_STATIC
{
    unsigned char ChiplVersion[8];
    unsigned char ToolVersion[8];
    unsigned char BuildFwTime[13];
    unsigned char UpdateFwTime[13];
} GL_CHIP_INFO_STATIC, *PGL_CHIP_INFO_STATIC;

typedef struct _GL_FW_INFO_STATIC
{
    unsigned char ToolVersion[7];
    unsigned char BuildFwTime[12];
    unsigned char UpdateFwTime[12];
} GL_FW_INFO_STATIC, *PGL_FW_INFO_STATIC;

typedef struct _GL_TOOL_STRING_STATIC
{
    unsigned char StringVersion;
    unsigned char MaskID[7];
    unsigned char MaskHubIC[6];
    unsigned char RunningHubID[7];
    unsigned char RunningHubIC[6];
    unsigned char FwVersion[4];
} GL_TOOL_STRING_STATIC, *PGL_TOOL_STRING_STATIC;

typedef struct _GL_TOOL_STRING_DYNAMIC
{
    unsigned char RunMode;
    unsigned char PortNumberSS;
    unsigned char PortNumberHS;
    unsigned char DeviceSS;
    unsigned char DeviceHS;
    unsigned char DeviceFS;
    unsigned char DeviceLS;
    unsigned char ChargingPort;
    unsigned char NonRemovePort;
    unsigned char Bonding1;
} GL_TOOL_STRING_DYNAMIC, *PGL_TOOL_STRING_DYNAMIC;

typedef struct _GL_STRING_DESCRIPTOR
{
    // char					InstID[MAX_PATH];
    GL_TOOL_STRING_STATIC StaticStr;
    GL_TOOL_STRING_DYNAMIC DynamicStr;
    GL_FW_INFO_STATIC FirmwareInfo;
} GL_STRING_DESCRIPTOR, *PGL_STRING_DESCRIPTOR;

typedef struct _GL_SS_HUB_BIN_INFO
{
    unsigned int BinFileType;
    bool SupportToolString;
    GL_STRING_DESCRIPTOR StringInfo;
    GL_CHIP_INFO_STATIC ChipInfo;
    unsigned char SPF5;           // Special Function 5
    unsigned char StrappingMask;  // Strapping Mask
    int CodeSize;
    bool compareFwVersion;
    int forciblyUpdateFwMode;  // 0:Update Block 0 1:Update Block 1 2:forcibly disable
    unsigned char BinChipID[7];
    unsigned char BondingOption;
    int BinChipIDVersion;
    bool isSupportDEM;
} GL_SS_HUB_BIN_INFO, *PGL_SS_HUB_BIN_INFO;

typedef struct _GL_USB_DEVHND
{
    unsigned long SerialNo;
} GL_USB_DEVHND, *PGL_USB_DEVHND;

typedef struct _GL_USB_DEVINFO
{
    GL_USB_DEVHND handle;
    unsigned int GLDevType;
    unsigned int VID;
    unsigned int PID;
    unsigned int bcdDev;
    unsigned int bcdUSB;
    unsigned char charged;
} GL_USB_DEVINFO, *PGL_USB_DEVINFO;

typedef enum
{
    BIT_OFFSET_0 = 0x01,
    BIT_OFFSET_1 = 0x02,
    BIT_OFFSET_2 = 0x04,
    BIT_OFFSET_3 = 0x08,
    BIT_OFFSET_4 = 0x10,
    BIT_OFFSET_5 = 0x20,
    BIT_OFFSET_6 = 0x40,
    BIT_OFFSET_7 = 0x80,

    BIT_OFFSET_END
} BIT_OFFSET;

typedef enum
{
    GL_BONDING_7394_A01 = 1,
    GL_BONDING_7394_B02 = 2,
    GL_BONDING_7394_C03 = 3,
    GL_BONDING_7436_A01 = 4,
    GL_BONDING_7436_B01 = 5,
    GL_BONDING_7436_C02 = 6,
    GL_BONDING_7436_D03 = 7,
    GL_BONDING_7441_A01 = 8,
    GL_BONDING_7441_B02 = 9,
    GL_BONDING_7441_C03 = 10,
    GL_BONDING_7441_D04 = 11,

    GL_BONDING_END
} GL_BONDING;

typedef enum
{
    GL7364_MASK_CODE_FW_VERSION_164     = 0x164,
    GL7344_MASK_CODE_FW_VERSION         = 0x301,
    GL7364_MASK_CODE_FW_VERSION         = 0x400,
    GL7364_MASK_CODE_FW_VERSION_401     = 0x401,
    GL7364_MASK_CODE_FW_VERSION_402     = 0x402,
    GL7394_MASK_CODE_FW_VERSION_500     = 0x500,
    GL7394_MASK_CODE_FW_VERSION_501     = 0x501,
    GL7394_MASK_CODE_FW_VERSION_502     = 0x502,
    GL7441_MASK_CODE_FW_VERSION_510     = 0x510,
    GL7441_MASK_CODE_FW_VERSION_511     = 0x511,
    GL8423_MASK_CODE_FW_VERSION_600     = 0x600,
    GL7423_MASK_CODE_FW_VERSION_601     = 0x601,
    GL7423_MASK_CODE_FW_VERSION_602     = 0x602,
    GL7423_MASK_CODE_FW_VERSION_610     = 0x610,
    GL7423A01_MASK_CODE_FW_VERSION_611  = 0x611,
    GL7423B02_MASK_CODE_FW_VERSION_612  = 0x612,
    GL7423C03_MASK_CODE_FW_VERSION_613  = 0x613,
    GL7423D04_MASK_CODE_FW_VERSION_614  = 0x614,
    GL7423E05_MASK_CODE_FW_VERSION_615  = 0x615,
    GL7423F06_MASK_CODE_FW_VERSION_616  = 0x616,
    GL7423G07_MASK_CODE_FW_VERSION_617  = 0x617,
    GL7423H08_MASK_CODE_FW_VERSION_618  = 0x618,
    GL7423I09_MASK_CODE_FW_VERSION_619  = 0x619,
    GL7448A001_MASK_CODE_FW_VERSION_628 = 0x628,  // (only USB2)
    GL7436_MASK_CODE_FW_VERSION_650     = 0x650,
    GL7436_MASK_CODE_FW_VERSION_651     = 0x651,
    GL7436_MASK_CODE_FW_VERSION_652     = 0x652,
    GL7436_MASK_CODE_FW_VERSION_653     = 0x653,
} MASK_CODE_FW_VERSION;

typedef enum eFLASH_TABLE
{
    FLASH_INFO_READ_FALSH_COMMAND            = 0,
    FLASH_INFO_READ_FLASH_COMMAND_LENGTH     = 1,
    FLASH_INFO_READ_DATA_1                   = 2,
    FLASH_INFO_READ_DATA_2                   = 3,
    FLASH_INFO_READ_DATA_3                   = 4,
    FLASH_INFO_ERASE_COMMAND                 = 5,
    FLASH_INFO_FLASH_WRITE_LENGTH            = 6,
    FLASH_INFO_RDID_DUMMY_ADDRESS            = 7,
    FLASH_INFO_EWSR                          = 8,
    FLASH_INFO_AAI_MODE_LOW                  = 9,
    FLASH_INFO_AAI_MODE_HIGH                 = 10,
    FLASH_INFO_ERASE_DELAY_TIME              = 11,
    FLASH_INFO_WRITE_DELAY_TIME              = 12,
    FLASH_INFO_UN_PROTECT_FLAG               = 13,
    FLASH_INFO_UN_PROTECT_COMMAND_1          = 14,
    FLASH_INFO_UN_PROTECT_COMMAND_2          = 15,
    FLASH_INFO_UN_PROTECT_COMMAND_3          = 16,
    FLASH_INFO_UN_PROTECT_COMMAND_4          = 17,
    FLASH_INFO_BLOCK_ERASE_COMMAND           = 18,
    FLASH_INFO_BLOCK_ERASE_LENGTH            = 19,
    FLASH_INFO_FLASH_SIZE                    = 20,
    FLASH_INFO_FLASH_SIZE_UNIT               = 21,
    FLASH_INFO_CHIP_ERASE_UNIT               = 22,
    FLASH_INFO_ADDRESS_MODE                  = 23,
    FLASH_INFO_FLASH_STATUE_REGISTER_COMMAND = 24,
    FLASH_INFO_FLASH_READ_ADDRESS_MODE       = 25,
    FALSH_INFO_ENTER_4_BYTE_ADDRESS_MODE     = 26,
    FALSH_INFO_EXIT_4_BYTE_ADDRESS_MODE      = 27,

    FALSH_INFO_COUNT
} FLASH_TABLE;

typedef enum eFLASH_OPERATE_CMD
{
    FOC_ERASE,
    FOC_WRITE,

    FOC_COUNT
} FLASH_OPERATE_CMD;

#define TOOL_STRING_VERSION_1 0x31
#define TOOL_STRING_VERSION_2 0x32
#define TOOL_STRING_VERSION_3 0x33
#define TOOL_STRING_VERSION_4 0x34
#define TOOL_STRING_VERSION_5 0x35

// Mask ID
#define GL_7394_A01 "7394001"
#define GL_7394_B02 "7394102"
#define GL_7394_C03 "7394203"
#define GL_7436_A01 "7436001"
#define GL_7436_B01 "7436101"
#define GL_7436_C02 "7436202"
#define GL_7436_D03 "7436303"
#define GL_7441_A01 "7441001"
#define GL_7441_B02 "7441102"
#define GL_7441_C03 "7441203"
#define GL_7441_D04 "7441304"
#define GL_8423_A01 "8423001"
#define GL_8423_B02 "8423102"
#define GL_7423_A01 "7423001"
#define GL_7423_B02 "7423102"
#define GL_7423_C03 "7423203"
#define GL_7423_D04 "7423304"
#define GL_7423_E05 "7423405"

#define GL7364_STRING "GLI7364"
#define GL5394_STRING "GLI5394"
#define GL7394_STRING "GLI7394"
#define GL7441_STRING "GLI7441"
#define GL7411_STRING "GLI7411"
#define GL7423_STRING "GLI7423"
#define GL7448_STRING "GLI7448"
#define GL8423_STRING "GLI8423"
#define GL7436_STRING "GLI7436"

extern unsigned char m_flashinfo[FLASH_TYPE_NUMBER][FALSH_INFO_COUNT];
extern char m_szDev[GLHUB_MAX_NUM][1024];
extern int m_devNum;
extern int m_flashcount;
extern int m_fdev[GLHUB_MAX_NUM];
extern DEV_INFO_GL m_devinfo[GLHUB_MAX_NUM];
extern bool m_bLoadEEP;

extern char m_szTargetVid[5];
extern char m_szTargetPid[5];

extern char m_configFilePath[MAX_BUF_LEN];
extern char m_containerID[WORD_CONTAINER_ID_LENGTH];
extern char* m_pConfigBuf;
extern char* m_pBinBuf;
extern char* m_pEepBuf;
extern bool m_ispOK;
extern bool m_doingISP;
extern bool m_bHintToggle;
extern char* m_eepFileName[MAX_BUF_LEN];
extern char* m_binFileName[MAX_BUF_LEN];
extern char* m_eepFilePath[MAX_BUF_LEN];
extern char* m_binFilePath[MAX_BUF_LEN];

extern int m_hubType[GLHUB_MAX_NUM];
extern int m_BinType[GLHUB_MAX_NUM];
extern unsigned int m_hubVid;
extern unsigned int m_hubPidHs;
extern unsigned int m_hubPidSs;
extern unsigned long m_iEraseDelay[GLHUB_MAX_NUM];
extern unsigned long m_iWriteDelay[GLHUB_MAX_NUM];

extern bool m_bMaskRomCode[GLHUB_MAX_NUM];
extern GL_STRING_DESCRIPTOR m_GlStrDes[GLHUB_MAX_NUM];
extern bool m_biniSupportMultiINOUT;

extern unsigned int m_2BinSize[GLHUB_MAX_NUM];
extern unsigned int m_eepSize[GLHUB_MAX_NUM];

bool hub_erase_firmware(int iHubIndex);
bool hub_read_fw_version(void);
bool hub_list_tree(void);
bool hub_software_reset(int iHubIndex);
bool hub_switch_speed(int iHubIndex, int iUsbSpeed);
bool hub_list_info(void);

bool OpenDevices(void);
void CloseDevices(void);
bool DoIsp(int iHubIndex);
bool SoftwareReset(int iHubIndex);
bool SwitchUsbSpeed(int iHubIndex, int iUsbSpeed);
bool HubIspInit(void);

int readBinFileFromIni(int iHubIndex);
int readBinFileName(int iHubIndex, char* binFileName);

int Return3523Bonding(GL_STRING_DESCRIPTOR glStr);
int Return3523BinBonding(PGL_SS_HUB_BIN_INFO pGlBinInfo);
int ReturnMaskCodeChipID(GL_USB_DEVINFO DevInfo, GL_STRING_DESCRIPTOR glStr, int iHubIndex);

#endif
