#include "define.h"
#include "scan.h"
#include "Hub.h"

const char* errno_shortname[] = {
    "SUCCESS",         /* 0 */
    "EPERM",           /* 1 */
    "ENOENT",          /* 2 */
    "ESRCH",           /* 3 */
    "EINTR",           /* 4 */
    "EIO",             /* 5 */
    "ENXIO",           /* 6 */
    "E2BIG",           /* 7 */
    "ENOEXEC",         /* 8 */
    "EBADF",           /* 9 */
    "ECHILD",          /* 10 */
    "EAGAIN",          /* 11 */
    "ENOMEM",          /* 12 */
    "EACCES",          /* 13 */
    "EFAULT",          /* 14 */
    "ENOTBLK",         /* 15 */
    "EBUSY",           /* 16 */
    "EEXIST",          /* 17 */
    "EXDEV",           /* 18 */
    "ENODEV",          /* 19 */
    "ENOTDIR",         /* 20 */
    "EISDIR",          /* 21 */
    "EINVAL",          /* 22 */
    "ENFILE",          /* 23 */
    "EMFILE",          /* 24 */
    "ENOTTY",          /* 25 */
    "ETXTBSY",         /* 26 */
    "EFBIG",           /* 27 */
    "ENOSPC",          /* 28 */
    "ESPIPE",          /* 29 */
    "EROFS",           /* 30 */
    "EMLINK",          /* 31 */
    "EPIPE",           /* 32 */
    "EDOM",            /* 33 */
    "ERANGE",          /* 34 */
    "ENOMSG",          /* 35 */
    "EIDRM",           /* 36 */
    "ECHRNG",          /* 37 */
    "EL2NSYNC",        /* 38 */
    "EL3HLT",          /* 39 */
    "EL3RST",          /* 40 */
    "ELNRNG",          /* 41 */
    "EUNATCH",         /* 42 */
    "ENOCSI",          /* 43 */
    "EL2HLT",          /* 44 */
    "EDEADLK",         /* 45 */
    "ENOTREADY",       /* 46 */
    "EWRPROTECT",      /* 47 */
    "EFORMAT",         /* 48 */
    "ENOLCK",          /* 49 */
    "ENOCONNECT",      /* 50 */
    "EL2HLT",          /* 51 */
    "ESTALE",          /* 52 */
    "EDIST",           /* 53 */
    "EWOULDBLOCK",     /* 54 */
    "EINPROGRESS",     /* 55 */
    "EALREADY",        /* 56 */
    "ENOTSOCK",        /* 57 */
    "EDESTADDRREQ",    /* 58 */
    "EMSGSIZE",        /* 59 */
    "EPROTOTYPE",      /* 60 */
    "ENOPROTOOPT",     /* 61 */
    "EPROTONOSUPPORT", /* 62 */
    "ESOCKTNOSUPPORT", /* 63 */
    "EOPNOTSUPP",      /* 64 */
    "EPFNOSUPPORT",    /* 65 */
    "EAFNOSUPPORT",    /* 66 */
    "EADDRINUSE",      /* 67 */
    "EADDRNOTAVAIL",   /* 68 */
    "ENETDOWN",        /* 69 */
    "ENETUNREACH",     /* 70 */
    "ENETRESET",       /* 71 */
    "ECONNABORTED",    /* 72 */
    "ECONNRESET",      /* 73 */
    "ENOBUFS",         /* 74 */
    "EOVERFLOW",       /* 75 (Rename to 'EOVERFLOW' as linux, original is 'EISCONN' in aix) */
    "ENOTUNIQ",        /* 76 (Rename to 'ENOTUNIQ' as linux that original is 'ENOTCONN' in aix) */
    "ESHUTDOWN",       /* 77 */
    "ETIMEDOUT",       /* 78 */
    "ECONNREFUSED",    /* 79 */
    "EHOSTDOWN",       /* 80 */
    "EHOSTUNREACH",    /* 81 */
    "ERESTART",        /* 82 */
    "EPROCLIM",        /* 83 */
    "EUSERS",          /* 84 */
    "ELOOP",           /* 85 */
    "ENAMETOOLONG",    /* 86 */
    "ENOTEMPTY",       /* 87 */
    "EDQUOT",          /* 88 */
    "ECORRUPT",        /* 89 */
    "EMSGSIZE",        /* 90 */
    "EPROTOTYPE",      /* 91 */
    "ENOPROTOOPT",     /* 92 */
    "EREMOTE        ", /* 93 */
    "ESOCKTNOSUPPORT", /* 94 */
    "EOPNOTSUPP",      /* 95 */
    "EPFNOSUPPORT",    /* 96 */
    "EAFNOSUPPORT",    /* 97 */
    "EADDRINUSE",      /* 98 */
    "EADDRNOTAVAIL",   /* 99 */
    "ENETDOWN",        /* 100 */
    "ENETUNREACH",     /* 101 */
    "ENETRESET",       /* 102 */
    "ECONNABORTED",    /* 103 */
    "ECONNRESET",      /* 104 */
    "ENOBUFS",         /* 105 */
    "EISCONN",         /* 106 */
    "ENOTCONN",        /* 107 */
    "ESHUTDOWN",       /* 108 */
    "ENOSYS",          /* 109 */
    "EMEDIA",          /* 110 */
    "ESOFT",           /* 111 */
    "ENOATTR",         /* 112 */
    "ESAD",            /* 113 */
    "ENOTRUST",        /* 114 */
    "ETOOMANYREFS",    /* 115 */
    "EILSEQ",          /* 116 */
    "ECANCELED",       /* 117 */
    "ENOSR",           /* 118 */
    "ETIME",           /* 119 */
    "EBADMSG",         /* 120 */
    "EPROTO",          /* 121 */
    "ENODATA",         /* 122 */
    "ENOSTR",          /* 123 */
    "ENOTSUP",         /* 124 */
    "EMULTIHOP",       /* 125 */
    "ENOLINK",         /* 126 */
    "EKEYEXPIRED"      /* 127 */
    "EKEYREVOKED",     /* 128 */
    "EKEYREJECTED",    /* 129 */
    "EOWNERDEAD",      /* 130 */
    "ENOTRECOVERABLE", /* 131 */
    "ERFKILL"          /* 132 */
};

unsigned char m_flashinfo[FLASH_TYPE_NUMBER][FALSH_INFO_COUNT];
char m_szDev[GLHUB_MAX_NUM][1024];
int m_flashcount;
int m_fdev[GLHUB_MAX_NUM];
DEV_INFO_GL m_devinfo[GLHUB_MAX_NUM];
bool m_bLoadEEP;

char m_szTargetVid[5] = GL_VID_STR;
char m_szTargetPid[5] = GL_PID_U2_STR;

char m_configFilePath[MAX_BUF_LEN];
char m_containerID[WORD_CONTAINER_ID_LENGTH];
char* m_pConfigBuf;
char* m_pBinBuf;
char* m_pEepBuf;
bool m_ispOK;
bool m_doingISP;
bool m_biniSupportMultiINOUT;
char* m_eepFileName[MAX_BUF_LEN];
char* m_binFileName[MAX_BUF_LEN];
char* m_eepFilePath[MAX_BUF_LEN];
char* m_binFilePath[MAX_BUF_LEN];
bool m_bMaskRomCode[GLHUB_MAX_NUM];
GL_STRING_DESCRIPTOR m_GlStrDes[GLHUB_MAX_NUM];

int m_hubType[GLHUB_MAX_NUM];
int m_BinType[GLHUB_MAX_NUM];
unsigned int m_hubVid;
unsigned int m_hubPidHs;
unsigned int m_hubPidSs;
unsigned long m_iEraseDelay[GLHUB_MAX_NUM];
unsigned long m_iWriteDelay[GLHUB_MAX_NUM];

int m_devNum;
unsigned int m_2BinSize[GLHUB_MAX_NUM];
unsigned int m_eepSize[GLHUB_MAX_NUM];
